summaryrefslogtreecommitdiff
path: root/dist/travis/script.sh
diff options
context:
space:
mode:
Diffstat (limited to 'dist/travis/script.sh')
-rw-r--r--dist/travis/script.sh48
1 files changed, 34 insertions, 14 deletions
diff --git a/dist/travis/script.sh b/dist/travis/script.sh
index 55c6890..7d3871b 100644
--- a/dist/travis/script.sh
+++ b/dist/travis/script.sh
@@ -18,20 +18,40 @@ case $OS in
;;
Darwin)
- # forcing brew versions (of gettext) over Mac versions
- export CFLAGS=-I/usr/local
- export CXXFLAGS=-I/usr/local
- export LDFLAGS=-L/usr/local/lib
- mkdir build
- cd build
- cmake \
- -DCMAKE_INSTALL_PREFIX=/usr/local -DCMAKE_BUILD_TYPE=Release \
- -DCMAKE_CXX_FLAGS=-g -G Xcode \
- ..
- xcodebuild -configuration Release -target ALL_BUILD
- xcodebuild -configuration Release -target RUN_TESTS
- sudo xcodebuild -configuration Release -target install
- cd ..
+ if test "X$CC" = "Xgcc"; then
+ # gcc on OSX is a mere frontend to clang, force using gcc 4.8
+ export CXX=g++-4.8
+ export CC=gcc-4.8
+ # forcing brew versions (of gettext) over Mac versions
+ export CFLAGS=-I/usr/local
+ export CXXFLAGS=-I/usr/local
+ export LDFLAGS=-L/usr/local/lib
+ mkdir build
+ cd build
+ cmake \
+ -DCMAKE_INSTALL_PREFIX=/usr/local -DCMAKE_BUILD_TYPE=Release \
+ -DCMAKE_CXX_FLAGS=-g -G 'Unix Makefiles' \
+ ..
+ make VERBOSE=1
+ make VERBOSE=1 test
+ sudo make VERBOSE=1 install
+ cd ..
+ else
+ # forcing brew versions (of gettext) over Mac versions
+ export CFLAGS=-I/usr/local
+ export CXXFLAGS=-I/usr/local
+ export LDFLAGS=-L/usr/local/lib
+ mkdir build
+ cd build
+ cmake \
+ -DCMAKE_INSTALL_PREFIX=/usr/local -DCMAKE_BUILD_TYPE=Release \
+ -DCMAKE_CXX_FLAGS=-g -G Xcode \
+ ..
+ xcodebuild -configuration Release -target ALL_BUILD
+ xcodebuild -configuration Release -target RUN_TESTS
+ sudo xcodebuild -configuration Release -target install
+ cd ..
+ fi
;;
*)